@@ -14,7 +14,7 @@ use constant {
 };
 
 
-our $VERSION = '0.042'; # VERSION
+our $VERSION = '0.058'; # VERSION
 
 has cur_comb_idx => ( is => 'rw', lazy_build => 1 );
 
@@ -49,7 +49,7 @@ sub next_comb {
     return $self->cur_comb;
 }
 
-sub start {
+sub range {
     my ( $self, $idx_range ) = @_;
 
     if ( $self->_iterating ) {
@@ -137,7 +137,7 @@ Bio::Grid::Run::SGE::Iterator::AllvsAll - Runs all elements of one index against
 
     # run through all combinations
     my ($from, $to) = (0, $it->num_comb - 1);
-    $it->start( [ $from, $to]  );
+    $it->range( [ $from, $to]  );
 
     my @result;
     my $i = $from;
