@@ -14,7 +14,7 @@ use constant {
     BEYOND_LAST_ELEMENT => -2,
 };
 
-our $VERSION = '0.042'; # VERSION
+our $VERSION = '0.058'; # VERSION
 
 has cur_comb_idx => ( is => 'rw', lazy_build => 1 );
 
@@ -55,7 +55,7 @@ sub next_comb {
     return $self->cur_comb;
 }
 
-sub start {
+sub range {
     my ( $self, $idx_range ) = @_;
 
     if ( $self->_iterating ) {
