@@ -12,7 +12,7 @@ use constant {
     BEYOND_LAST_ELEMENT => -2,
 };
 
-our $VERSION = '0.042'; # VERSION
+our $VERSION = '0.058'; # VERSION
 
 has cur_comb_idx => ( is => 'rw', lazy_build => 1 );
 
@@ -47,7 +47,7 @@ sub next_comb {
     return $self->cur_comb;
 }
 
-sub start {
+sub range {
     my ( $self, $idx_range ) = @_;
 
     if ( $self->_iterating ) {
@@ -121,7 +121,7 @@ __END__
 
     # run through all combinations
     my ($from, $to) = (0, $it->num_comb - 1);
-    $it->start( [ $from, $to]  );
+    $it->range( [ $from, $to]  );
 
     my @result;
     my $i = $from;
