@@ -20,7 +20,7 @@ for ( my $job_id = 1; $job_id < 100; $job_id++ ) {
 sub do_worker_stuff {
     my ( $c, $result_prefix, $seq_file ) = @_;
 
-    INFO "Running $seq_file -> $result_prefix";
+    job->log->info("Running $seq_file -> $result_prefix");
     open my $seq_file_fh, '<', $seq_file or confess "Can't open filehandle: $!";
 
     open my $result_fh, '>', $result_prefix or confess "Can't open filehandle: $!";
